function y = Gaussian2DSmo(inputMat,SpatFilterWidth,SpatFilterSTD)
%
% Gaussian2DSmo
% performs 2D gaussian smoothing on an input matrix
% inputs: 
% inputMat  = input matrix to be smoothed
% SpatFilterWidth = width in pixels of the full gaussian smoothing filter
% SpatFilterSTD = standard deviation of the gaussian smoothing filter 
%
% outputs:
% y = gaussian smoothed matix

x = -1/2:1/(SpatFilterWidth-1):1/2;
[Y,X] = meshgrid(x,x);
f = exp( -(X.^2+Y.^2)/(2*SpatFilterSTD^2) );
f = f / sum(f(:));
n1 = size(inputMat,1); n2 = size(inputMat,2); p = length(f);
if mod(p,2)==1
d1 = (p-1)/2; d2 = (p-1)/2;
else
d1 = p/2-1; d2 = p/2;
end
xx = [ inputMat(d1:-1:1,:); inputMat; inputMat(end:-1:end-d2+1,:) ];
xx = [ xx(:,d1:-1:1), xx, xx(:,end:-1:end-d2+1) ];
y = conv2(xx,f);
y = y( (2*d1+1):(2*d1+n1), (2*d1+1):(2*d1+n2) );