function RegionStats = LRcellfinder_ari_onlyZscores_6(~,forcealpha,quadr, regressorConv)
%clear vid2 
clear -global Go Gc
clear G
global pMap zThMap grayPlusSupraThreshRGB quadr smoOverlayRGB  scaledMeanIm Xtrim time  baselineFrames Go G X tau
global ceBinarySignMap smoZMapVector size1 size2 frameTime orthog mainR RegionStats FDRalpha zMap bestFDRpThresh
%global pixcorrmap usePixCorr useZ_pic FTimeSeries p FTimeSeriesSort

% LRcellfinder 
% a function for using linear regression of a fluorescence image time series to identify cells showing significant regressor correlation
% Identification can be done either automatically or manually (see lines 196-217)
%
% INPUTS:
% X is the image time series, preferably motion-corrected; dim 1 is image rows, dim 2 is image columns, and dim 3 are the image frames
% G is the size(X,3) x m matrix of regressors where m is the number of regressors; this function will calculate T scores measuring data correlation with a 
% CIRF-convolved version of the first regressor
% manuall is 1 for drawing ROIS manually
% forcealpha is 1 for ignoring the FDR code and use the FDR alpha straight
% quadr is the Quadrant that is analyzed (a 512x512 time series can be
% split in four 256x256 time series). 

% PARAMETERS:
% regressorConv = [1 1 0]; % a binary vector with one element for each column of G determining whether or not that column should be CIRF-convolved before regression.  
%                          %   e.g. [1 1 0] will cause the first two columns to be convolved, but not the third column

omits = [];               % vector of frame numbers for omission
MaxPixelIntensity = 255;  % highest value a pixel can take
alpha = 0.15;             % desired rate of false discovery
BSsamps = 1000;           % bootstrap samples used in FDR threshold calculation
BSiters = 100;            % bootstrap iterations used in FDR threshold calculation
CellSizeMin =75;          % number of pixels corresponding to the smallest allowable cell
CellSizeMax = 400;        % region area in terms of pixels above which it will be segmented into different cells
SpatFilterWidth = 10;     % width in terms of pixels for the spatial smoothing  of the correlation maps before the segmentation is performed
SpatFilterSTD = 0.04;     % standard deviation for this filter; depends on filter width
MaxCellWidth = 30;        % maximum width in terms of pixels of cells found during segmentation
baselineFrames = 25;      % number of frames to include in calculating baseline fluorescence for each identified cell
NumSearchDirections = 16; % number of directions for searching radial outward in finding somatic boundaries during segmentation

time = frameTime:frameTime:frameTime*size(X,3);

% OUTPUTS:
% RegionStats = a data struct with a list of pixels, centroid, cell area, delta F/F time series, a vector of regressor correlations, and a mask matrix for each cell

%Eliminate data according to the frame numbers listed in omits; regressors and time vector are similarly shortened
keep = zeros(1,size(X,3)-size(omits,3));
n = 1;
if ~isempty(omits)
    for k = 1:size(X,3)
        if ~ismember(k,omits)
            keep(n) = k;
            n = n+1;
        end
    end
    Xtrim = X(:,:,keep);
    G = G(keep,:);
    time = time(keep);
else Xtrim = X;
end
size1 = size(Xtrim,1);
size2 = size(Xtrim,2);
size3 = size(Xtrim,3);

%Convolve regressors with an exponential impulse response
CIRF = exp(-time/tau); %define the calcium impulse response function
Gc = G;
for k = 1:size(G,2) %Here we don't convolve the final regressor, which is average frame fluorescence
    if regressorConv(k) == 1
        zeroPadded = [zeros(1,size3) G(:,k)' zeros(1,size3)]; %pad the regressor with zeros prioir to convolution
        convReg = conv(zeroPadded,CIRF);
        Gc(:,k) =  convReg(size3+1:size3*2);
    end
end

% 120508ari:orthogonalization does not have a lot of use for us for now,
% since we don't want to calculate the proportion of velocity vs. position
% encoding. We want to add multiple regressors, so orthogonalization will
% likely not work/cause confusion. 

Go=zeros(size(Gc));
if orthog==1
    %Orthogonalize the regressors
    Go = Gram_Schmidt_Process(Gc);
elseif orthog==0
    for i=1:length(Gc(1,:))
        if norm(Gc(:,i))~=0
        Go(:,i)=Gc(:,i)/norm(Gc(:,i)); %just normalization, no orthogonalization.
        elseif norm(Gc(:,i))==0
        Go(:,i)=0;
        end
    end
end

%make 2D matrix out of movie, each row is a pixel time series
XtrimRS = reshape(Xtrim,size1*size2,size3);

% Eliminate pixels for which the signal is very low or nonexistant (railing against 0)
% 140709: for calcium indicators with very low baseline fluorescence and low expression level (e.g.
% GCaMP6f), the ommission criterion of the low standard deviation doesn't
% work: it actually blocks the pixels with the highest signals from being
% considered. This was likely sometimes also a problem with GCaMP5G.
% Solution: Deletion of this criterion. 
means = mean(XtrimRS,2);
stds = std(XtrimRS,0,2);
% omittedRows = [find((means-2*stds)<=0.01); find(means == MaxPixelIntensity)]; %these are the pixel time series omitted from the data
omittedRows = [find(means == MaxPixelIntensity)]; %these are the pixel time series omitted from the data, %140709
% omittedRows = [find((means-1*stds)<=0.01); find(means == MaxPixelIntensity)]; %these are the pixel time series omitted from the data
XtrimRS(omittedRows,:) = []; 

%bring main regressor into first column (for use of different main
%regressors in z-image 120511ari
temp=Go(:,mainR);
Go_shift=Go;
Go_shift(:,mainR)=Go(:,1);
Go_shift(:,1)=temp;

%Solve the regression equation
Xnorm = ((XtrimRS - repmat(mean(XtrimRS,2),1,size3)))'; %subtracts the mean of each pixel time series
Beta = Go_shift'*Xnorm;       % calculate the regression coefficients
Res = Xnorm - Go_shift*Beta;  % calculate the residuals of the fit

%Calculate the T scores for measuring data correlation with CIRF-convolved first regressor
v = (size3-size(Go_shift,2)); % calculate the degree of freedom
epsiSq = sum(Res.^2)/v;       % calculate the sum squared residuals, divided by the number of degrees of freedom 
T = Beta(1,:)./((epsiSq).^0.5); 

%Now convert to T scores to Z scores
%Since some Z scores will be infinite, they are kept as the T score; there should in general be very little difference between the two 
%for large degrees of freedom.
Z = T*0;                      % makes a zero matrix of the same size as T
co=0; 
for n = 1:size(T,2) 
    ConvT = icdf('Normal',tcdf(T(1,n),v),0,1); % Use a mapping between cumulative distribution functions
    if isfinite(ConvT)
        Z(1,n) = ConvT;
    else
        Z(1,n) = T(1,n);
        if isnan(Z(1,n)) 
            Z(1,n)=0; 
            co=co+1;
        end 
    end
end
number_of_NaN_pixels=co; %140618

%Now correct for motion-induced correlations using the magnitude of the spread of the negative half of the distribution
lessThanZero = Z(find(Z<0));                % Zscores less than 0
fullNegDist = [lessThanZero -lessThanZero]; % pseudo distribution using negative part of Z distribution
NegStd = std(fullNegDist);                  % calc the STD of this pseudo distribution
Z = Z/NegStd;                               % Normalizes the Z scores

%set large positive Z scores no larger than 10 to makes color scales appear better
Zth = Z;
ind = find(Z>10);
Zth(ind) = 10;

%Convert Z scores to p-values as if doing a double sided test of Z stats
pVals = 2*cdf('norm',-abs(Z),0,1);

%Calculate p threshold to control the rate of falsely discovering pixels as significant
if forcealpha==0
bestFDRpThresh = FDRcontP_ari(pVals,alpha,BSsamps,BSiters); % uses Storey method for finding threshold that controls FDR at rate <= alpha;
elseif forcealpha==1
%     bestFDRpThresh=alpha
bestFDRpThresh=FDRalpha;
end

ZscoresThresholded = Zth.*(pVals<bestFDRpThresh);           % The Z scores corresponding to p values below the FDR controlling threshold are maintained, the rest set to 0
MeanIm = mean(Xtrim,3);                                     % mean image of the movie
scaledMeanIm = (MeanIm/max(MeanIm(:)))*255+1;               % scaled version of the mean image
pMap = zeros(size1,size2);                                  % zeros matrix for an image of all the p values
zMap = zeros(size1,size2);                                  % zeros matrix for an image of all the Z scores
zThMap = zeros(size1,size2);                                % zeros matrix for an image of all the Z scores, values above 10 set to 10
h=waitbar(0,'Assembling Images');                           % use a nifty waitbar to track progress
grayPlusSupraThreshRGB = zeros(size1,size2,3);              % zeros array for what will be a gray image with supra-threshold pixels colored green to red
c2 = colormap(jet(256));
c1 = colormap(gray(256));

c3 = c2([131:240],:); 
c4 = flipud(c2([1:60],:));
minZpos = min(ZscoresThresholded(find(ZscoresThresholded>0)));      % min suprathreshold Z score
maxZpos = max(ZscoresThresholded(find(ZscoresThresholded>0)));      % max suprathreshold Z score
minZneg = abs(max(ZscoresThresholded(find(ZscoresThresholded<0)))); % min suprathreshold Z score
maxZneg = abs(min(ZscoresThresholded(find(ZscoresThresholded<0)))); % max suprathreshold Z score
ind = 1;
for j = 1:size1*size2 %This for loop fills up the three images zMap, pMap and grayPlusSupraThreshRGB
    col = ceil(j/size1);
    row = j-(col-1)*size1;
    if ismember(j,omittedRows)
        grayPlusSupraThreshRGB(row,col,:) = c1(ceil(scaledMeanIm(row,col)),:);
        pMap(row,col) = 1;
        zMap(row,col) = 0;
        zThMap(row,col) = 0;
    elseif ZscoresThresholded(ind) == 0
        grayPlusSupraThreshRGB(row,col,:) = c1(ceil(scaledMeanIm(row,col)),:);
        pMap(row,col) = pVals(ind);
        zMap(row,col) = Z(ind);
        zThMap(row,col) = Zth(ind);
        ind = ind+1;
    elseif ZscoresThresholded(ind) < 0
        grayPlusSupraThreshRGB(row,col,:) = c4(ceil(((abs(ZscoresThresholded(ind))-minZneg+0.001)/(maxZneg-minZneg))*59),:);
        pMap(row,col) = pVals(ind);
        zMap(row,col) = Z(ind);
        zThMap(row,col) = Zth(ind);
        ind = ind+1;
    else   
        grayPlusSupraThreshRGB(row,col,:) = c3(ceil(((ZscoresThresholded(ind)-minZpos+0.001)/(maxZpos-minZpos))*109),:);
        pMap(row,col) = pVals(ind);
        zMap(row,col) = Z(ind);
        zThMap(row,col) = Zth(ind);
        ind = ind+1;
    end
    if rem(j,100)==0
        waitbar(j/(size1*size2),h,'Assembling Images'); % update the waitbar to reflect progress
    end
end
close(h);                                               % close the waitbar

%Use a contextual enhancement algorithm to smooth significant regions
pMapinv = 1-pMap;
ceBinarySignMap = conEnhance(pMapinv,(1-bestFDRpThresh),(1-bestFDRpThresh)^2/6); 


%Make different images of the significance in image space
%creates a zeros array for generation of a grayscale image with suprthreshold z scores shown in color, looks like previous RGB image, but with edges enhanced
h=waitbar(0,'Assembling Another Image');                  % use a nifty waitbar to track progress
BinarySignMapVector = ceBinarySignMap(:);
smoZMapVector = zThMap(:).*ceBinarySignMap(:);            % returns a thresholded smoothed zMap
minZpos = min(smoZMapVector(find(smoZMapVector>0)));      % min suprathreshold Z score
maxZpos = max(smoZMapVector(find(smoZMapVector>0)));      % max suprathreshold Z score
minZneg = abs(max(smoZMapVector(find(smoZMapVector<0)))); % min suprathreshold Z score
maxZneg = abs(min(smoZMapVector(find(smoZMapVector<0)))); % max suprathreshold Z score
smoOverlayRGB = zeros(size1,size2,3);                     % zeros array for what will be a gray image with supra-threshold regions colored

for j = 1:size1*size2                                     %  this is for loop populates smoOverlayRGB
    col = ceil(j/size1);
    row = j-(col-1)*size1;
    if BinarySignMapVector(j)>0.5 && smoZMapVector(j) > 0
        smoOverlayRGB(row,col,:) = c3(ceil((smoZMapVector(j)-minZpos+0.001)/(maxZpos-minZpos)*109),:);
    elseif BinarySignMapVector(j)>0.5 && smoZMapVector(j) < 0
        smoOverlayRGB(row,col,:) = c4(ceil((abs(smoZMapVector(j))-minZneg+0.001)/(maxZneg-minZneg)*59),:);
    else smoOverlayRGB(row,col,:) = c1(ceil(scaledMeanIm(row,col)),:);
    end
    ori_smoOverlayRGB(row,col,:) = c1(ceil(scaledMeanIm(row,col)),:);  % addded  Kun
    if rem(j,100)==0
        waitbar(j/(size1*size2),h,'Assembling Another Image');         % updates the waitbar to reflect progress
    end
end

 for i=1:length(RegionStats)
     text (RegionStats(i).Centroid(1), RegionStats(i).Centroid(2),[num2str(i)])
 end      % Ari:plotnumber
close(h); % close the waitbar





