function manuall=LRcellfinder_onlyROIs_4automaticROIselect
% Now we find cells, making a "mask" for each one
% Choose either of two methods for cell finding
% Generate a data struct "RegionStats" with a list of pixels, centroid, and area for each cell
global pMap zThMap grayPlusSupraThreshRGB quadr smoOverlayRGB pixcorrmap usePixCorr useZ_pic useZ_picsmo scaledMeanIm Xtrim time FTimeSeries p FTimeSeriesSort baselineFrames RegionStats Go X G ceBinarySignMap
global smoZMapVector size1 size2 mainR tau FDRalpha velocitythresh frameTime wasbinned zMap bestFDRpThresh gscaledMeanIm smoZMap ZthreshFDR

CellSizeMin =15;          % number of pixels corresponding to the smallest allowable cell
CellSizeMax = 25;         % region area in terms of pixels above which it will be segmented into different cells
SpatFilterWidth = 10;     % width in terms of pixels for the spatial smoothing  of the correlation maps before the segmentation is performed
SpatFilterSTD = 0.04;     % standard deviation for this filter; depends on filter width
MaxCellWidth = 6;         % maximum width in terms of pixels of cells found during segmentation
                          % number of frames to include in calculating baseline fluorescence for each identified cell
NumSearchDirections = 16; % number of directions for searching radial outward in finding somatic boundaries during segmentation


 
ZthreshFDR = abs(icdf('normal',bestFDRpThresh/2,0,1));       % calculates the Z score that corresponds to the calculated p threshold
smoZMap = Gaussian2DSmo(zMap,SpatFilterWidth,SpatFilterSTD); % spatially smoothes the zMap

manuall=1;
if manuall==0
% Method 1: use FDR thresholded image to define cells automatically

gscaledMeanIm=Gaussian2DSmo(scaledMeanIm,SpatFilterWidth,SpatFilterSTD);
[masks,RegionStats,allOutlines] = AutoSeg_ari(size1,size2,ceBinarySignMap,CellSizeMin,CellSizeMax,ZthreshFDR,MaxCellWidth,smoZMap,NumSearchDirections);

elseif manuall==1
% Method 2: Manually Define the "cells" using the map of smoothed suprathreshold correlations

useZ = input(['Use suprathreshold Z picture?' char(13) '0 = no' char(13)  '1 = yes (w/o context enhancement)' char(13) '2 = yes (with context enhancement)']);
if useZ==1
    load(['useZ' [num2str(quadr)] '.mat']);
masks = select_polys_3_automatic(useZ_pic,4);
elseif useZ==2
    load(['useZ' [num2str(quadr)] '.mat']);
masks = select_polys_3_automatic(useZ_picsmo,5);
else
masks = select_polys_3_automatic(scaledMeanIm,4);
end
masks_corrim=masks;
masks = permute(masks,[2 3 1]);
maskSum = sum(masks,3);
allOutlines = edge(maskSum);
LabelMat = zeros(size1,size2);
numMasks = size(masks,3);
for i = 1:size1
    for j = 1:size2
        a = squeeze(masks(i,j,:)).*(1:numMasks)';
        LabelMat(i,j) = max(a);
    end
end
RegionStats= regionprops(LabelMat, 'PixelList','Centroid','Area');
end

%Plot the scaled mean image with cell outlines overlaid
OverlayIm2 = imoverlay(scaledMeanIm/max(scaledMeanIm(:)),logical(allOutlines),[1 0 0]); 
figure(1)
image(OverlayIm2); 
axis image
title('Identified cells outlined in red')

set(gcf,'Position',[10 10 600 600])
axis equal

figure(100)
image(OverlayIm2); 
axis image
title('Identified cells outlined in red')

grid on
set(gca,'Xtick',0:10:250,'Ytick',0:10:250,'Xcolor','g','Ycolor','m') %150310 Kun

set(gcf,'Position',[10 10 600 600])
axis equal

%This for loop gets the delta F/F time series for each cell, adds it to the RegionStats struct
for i = 1:size(masks,3) 
    mask = masks(:,:,i);
    FTimeSeries = (CalcTimeSeries(mask,Xtrim))';
    FTimeSeriesSort = sort(FTimeSeries);
    RegionStats(i).DFF = (FTimeSeries-mean(FTimeSeriesSort(1:baselineFrames)))/mean(FTimeSeriesSort(1:baselineFrames)); % converts to DF/F, using the lowest fluorescence values as baseline
    %  keep information about absolute fluorescence levels
    RegionStats(i).F = (FTimeSeries);
    RegionStats(i).Fb=mean(FTimeSeriesSort(1:baselineFrames));
    RegionStats(i).corrVec = corr(RegionStats(i).DFF',Go);  % calculates the correlation for the cell's DF/F time series with regressors
    if wasbinned==0;
    RegionStats(i).mask = mask;                             % defines the mask matrix for this cell
    elseif wasbinned==1;
    RegionStats(i).mask = imresize(mask,2);                 % defines the mask matrix for this cell
    RegionStats(i).Centroid = RegionStats(i).Centroid *2;
    end
    RegionStats(i).tau = tau;
    RegionStats(i).FDRalpha = FDRalpha;
    RegionStats(i).velocitythresh = velocitythresh;
    RegionStats(i).frametime = frameTime;
end

usePixCorr = 0;
%This loop calculates the correlation of each pixel's DF/F time series with the main regressor
if usePixCorr==1
    pixcorrmap=zeros(size(X,1),size(X,2));
    clear pixDFF
    h=waitbar(0,'Calculating pixelwise correlation');
    for j=1:size(X,2)
        for i=1:size(X,1)
            pixDFF=diff(X(i,j,:))./X(i,j,1:end-1);
            pixcorrmap(i,j)=corr(pixDFF(:),Go(1:end-1,mainR));        % pixelwise correlation with CONVOLVED MAIN REGRESSOR
            waitbar(((j-1)*size(X,2)+i)/(size(X,1)*size(X,2)),h,'Calculating pixelwise correlation');
        end
    end
    close(h)                                                          % close progress bar
else
end

figure(11)
%Plot the scaled mean image with cell outlines with an intensity code for the correlation coefficient

Corr_Im=scaledMeanIm*255/256;
Corr_Im_2=zeros(size(Corr_Im));
for i=1:length(masks_corrim(:,1,1) )
    temp=masks_corrim(i,:,:);
    Corr_Im(find(temp))=abs(RegionStats(i).corrVec(mainR))*255;
    Corr_Im_2(find(temp))=abs(RegionStats(i).corrVec(mainR))*255;
end
imagesc(Corr_Im);
colormap('gray')
    axis image
title('Cells colored according to correlation coefficient of ROI')
set(gcf,'Position',[10 10 600 600])
axis equal

figure(12)
imagesc(Corr_Im_2);
colormap('gray')
    axis image
title('Cells colored according to correlation coefficient of ROI')
set(gcf,'Position',[10 10 600 600])
axis equal

figure(13)
imagesc(scaledMeanIm*255/256);
colormap('gray')
    axis image
title('average fluorescence')
grid on
set(gca,'Xtick',0:10:250,'Ytick',0:10:250,'Xcolor','g','Ycolor','m')  % 150310 Kun
set(gcf,'Position',[10 10 600 600])
axis equal