function enhanced = conEnhance(sigScores,L,B)
% 
% conEnhance
% a function that runs a contextual enhancement algorithm to smooth the edges of regions of significantly correlated pixels
% inputs:
% sigScores = the map of 1 - p values, quantifying significance
% L is the significance threshold in terms of these sigScores
% B is the parameter that dictates how much contextual information to include in updating the sigScores
%
% outputs:
% enhanced = a binary map with pixels corresponding to smoothed contiguous regions are = 1, remaining pixels are = 0

%calculate an initial binary map
tMap = sigScores>L;

%Initialize variables
k = 1; %k is the number of iterations of enhancement run
check = 100; %a scaler quantity that will quantify the difference between subsequent tMaps
checkVec = []; %vector to which all the values of check are successively added 

% The following loop terminates if 
% 1. two successive tMaps are identical (check = 0)
% 2. the maps begin to alternate between 2 states (checkVec(end-3:end-2) == checkVec(end-1:end))
% 3. 50 iterations are reached
while check > 1
    tMapNew = 0*tMap; %set a map of zeros for the new tMap
    %Now populate the tMap
    for i = 2:size(tMap,1)-1
        for j = 2:size(tMap,2)-1
         neighborMat = tMap(i-1:i+1,j-1:j+1); %create a matrix with all the neighbors of pixel i,j
         activeNeighbors = sum(neighborMat(:))-tMap(i,j); %calculate the number that are active
         test = sigScores(i,j)+ (B/L)*(activeNeighbors-3.5); %calculate a new sigScore for pixel i,j
         tMapNew(i,j) = test>L; %update the tMap at i,j accordingly
        end
    end
    
    %calculate the difference between current and previous tMaps
    diffMat = tMap-tMapNew; 
    check = sum(abs(diffMat(:)));
    
    %Now check to see if its time to terminate
    if k > 4
        altCheck = checkVec(end-3:end-2) == checkVec(end-1:end);
        if sum(altCheck) == 2
            check = 0;
        end
    end
    if k > 50
        check = 0;
    end
    
    %update variable
    checkVec = [checkVec check];
    k = k+1;
    tMap = tMapNew;
end

%output  = he last tMap upon termination
enhanced = tMap;

       