function [outputregressors,names,regressorConv]=makeRegressors(data,selection)
%generates a list of regressors from the padded eyetracking data matrix
%'data', based on the selectors specified in a n x 4 string struct array
%('selection').outputregressors

%Bastian Hablitzel, 2013
%bastian.hablitzel@gmail.com

global velocitythresh AvgFrFl

outputregressors=zeros(size(data(:,1),1),size(selection,1));
names=cell(size(selection,1),1);
regressorConv=zeros(1,size(selection,1));
for j=1:size(selection,1)  %  cycle through selected regressor properties %%%

    names{j,1}=[selection{j,2}, selection{j,3}, selection{j,4}, selection{j,5}];
    clear rtemp1 rtemp2 rtemp3 choosedisp
    velreg=0; ambivalent=0;
%%  regressor for the visual stimulus presented from the big LED arena
        if strcmpi(selection{j,2},'StimBigArena')
        regressorConv(j)=1;
%         tempfreqON2=data(:,25)>0.4;        %  for the old data (datasets recorded in 2015)
        tempfreqON2=data(:,9)>0.4;           %  Kun Wang 2016/09/23  for new main controller pin; column 9; the (0 1) regressor form the big arena
        rtemp3=zeros(size(data,1),2);
        tempfreqON2=tempfreqON2(1:size(tempfreqON2),:);
        rtemp3(:,2)=tempfreqON2;

        end
%%  regressor for the eye position or velocity (useless in our data analysis)

    if strcmpi(selection{j,2},'eye')            %  eye-variable related regressors
        regressorConv(j)=1;
        if strcmpi(selection{j,3},'be')         %  both eyes
            rtemp1=data(:,[1,5:6]); singleeye=0;
        elseif strcmpi(selection{j,3},'le')     %  left eye
            rtemp1=data(:,[1,5]); singleeye=1;
        elseif strcmpi(selection{j,3},'re')     %  right eye
            rtemp1=data(:,[1,6]); singleeye=1;
        else
            error([num2str(j) 'unknown regressor subtype (level 3). aborting...']);
        end
        
        rtemp2=zeros(size(rtemp1));                      %  preallocation
        rtemp2(:,1)=rtemp1(:,1);
        rtemp3=zeros(size(rtemp2,1),2);
        rtemp3(:,1)=rtemp2(:,1);
        avgeyevel=diff((rtemp1(:,2)+rtemp1(:,end))/2);
        
        if strcmpi(selection{j,4},'pos')                 %  eye position
            rtemp2=rtemp1;
            if strcmpi(selection{j,5},'left')            %  left side eye position
                rtemp3(:,2)=-(rtemp2(:,2)+rtemp2(:,end))/2;
            elseif strcmpi(selection{j,5},'right')       %  right side eye position
                rtemp3(:,2)=(rtemp2(:,2)+rtemp2(:,end))/2;
            else
                error([num2str(j) 'unknown regressor subtype (level 5). aborting...']);
            end
            
        elseif strcmpi(selection{j,4},'rawvel')          %  unfiltered eye velocity
            rtemp2(2:end,2:end)=diff(rtemp1(:,2:end)); velreg=1;
        elseif strcmpi(selection{j,4},'lowvel')          %  filtered low eye-velocity
            rtemp2(2:end,2:end)=bsxfun(@times,(abs(avgeyevel)<velocitythresh),diff(rtemp1(:,2:end))); velreg=1;
        elseif strcmpi(selection{j,4},'hivel')           %  filtered high velocity
            rtemp2(2:end,2:end)=bsxfun(@times,(abs(avgeyevel)>velocitythresh),diff(rtemp1(:,2:end))); velreg=1;
        else
            error([num2str(j) 'unknown regressor subtype (level 4). aborting.']);
        end
        
        if velreg==1
            if singleeye==0
                
                if strcmpi(selection{j,5},'conjCW')
                    rtemp3(:,2)=(((rtemp2(:,2)+rtemp2(:,3))/2)>0).*((rtemp2(:,2)+rtemp2(:,3))/2);
                    disp('conjCW');
                elseif strcmpi(selection{j,5},'conjCCW')
                    rtemp3(:,2)=(((-rtemp2(:,2)-rtemp2(:,3))/2)>0).*((-rtemp2(:,2)-rtemp2(:,3))/2);
                    disp('conjCCW');
                elseif strcmpi(selection{j,5},'conv')
                    rtemp3(:,2)=(rtemp2(:,2)>0).*(-rtemp2(:,3)>0).*((rtemp2(:,2)-rtemp2(:,3))/2);
                elseif strcmpi(selection{j,5},'div')
                    rtemp3(:,2)=(-rtemp2(:,2)>0).*(rtemp2(:,3)>0).*((-rtemp2(:,2)+rtemp2(:,3))/2);
                else
                    error([num2str(j) 'unknown regressor subtype (level 5). aborting...'])
                end
            elseif singleeye==1
                if (strcmpi(selection{j,3},'LE') && strcmpi(selection{j,5},'TN')) || (strcmpi(selection{j,3},'RE') && strcmpi(selection{j,5},'NT')) % single eye clockwise (L T->N or R N->T)
                    rtemp3(:,2)=(rtemp2(:,2)>0).*rtemp2(:,2);
                elseif (strcmpi(selection{j,3},'LE') && strcmpi(selection{j,5},'NT')) || (strcmpi(selection{j,3},'RE') && strcmpi(selection{j,5},'TN')) % single eye counterclockwise (R T->N or L N->T)
                    rtemp3(:,2)=(-rtemp2(:,2)>0).*-rtemp2(:,2);
                else
                    error([num2str(j) 'unknown regressor subtype (level 5). aborting...'])
                end
            end
        end
        
        
        filter=zeros(1,4);
    elseif strcmpi(selection{j,2},'stim') % stimulus related regressors
        regressorConv(j)=1;
        rtemp3=zeros(size(data,1),2);
        rtemp3(:,1)=data(:,1);
        tempfreqON=data(:,24)>0.4; 
        tempfreq=tempfreqON.*data(:,24);  % set still stimulus frames = 0 %% KA WAS DAS SOLL NOCH ANSCHAUN       
        if strcmpi(selection{j,3},'BE')              %  both eyes
            filter(1,1:2)=[1,1]; choosedisp=[18,19];
            if strcmpi(selection{j,5},'conjCW')      %  conjugate clockwise
                filter(1,3:4)=[0,0];
            elseif strcmpi(selection{j,5},'conjCCW') %  conjugate counter-clockwise
                filter(1,3:4)=[1,0];
            elseif strcmpi(selection{j,5},'conv')    %  convergent
                filter(1,3:4)=[0,1];
            elseif strcmpi(selection{j,5},'div')     %  divergent
                filter(1,3:4)=[1,1];
            elseif strcmpi(selection{j,5},'')        %  no selector 5
            else
                error([num2str(j) 'unknown regressor subtype (level 5). aborting...']);
            end
            
        elseif strcmpi(selection{j,3},'LE')     %  left eye
            filter(1,1:2)=[1,0]; choosedisp=18;
            if strcmpi(selection{j,5},'nt')     %  naso-temporal
                filter(1,3:4)=[1,0];
            elseif strcmpi(selection{j,5},'tn') %  temporo-nasal
                filter(1,3:4)=[0,0];
            elseif strcmpi(selection{j,5},'')   %  no selector 5
            else
                error([num2str(j) 'unknown regressor subtype (level 5). aborting...']);
            end
            
        elseif strcmpi(selection{j,3},'RE')     %  right eye
            filter(1,1:2)=[0,1]; choosedisp=19;
            if strcmpi(selection{j,5},'nt')     %  naso-temporal
                filter(1,3:4)=[0,0];
            elseif strcmpi(selection{j,5},'tn') %  temporo-nasal
                ambivalent=1;                   %  two possibilities
                filter(1,3:4)=[1,0];
                filter2=filter;
                filter2(1,3:4)=[0,1];
            elseif strcmpi(selection{j,5},'')   %  no selector 5
            else
                error([num2str(j) 'unknown regressor subtype (level 5). aborting...']);
            end
                
        elseif strcmpi(selection{j,3},'ANY')    %  LE, RE or BE
            filter(:,1:2)=[1,0];
            filter2(:,1:2)=[0,1];
            filter3(:,1:2)=[1,1];
            ambivalent=2;
            if strcmpi(selection{j,5},'CW')      %  clockwise
                filter(3:4)=[0,0];
                filter2(3:4)=[0,0];
                filter3(3:4)=[0,0];
            elseif strcmpi(selection{j,5},'CCW') %  counterclockwise
                filter(:,3:4)=[1,0];
                filter2(:,3:4)=[1,0];
                filter3(:,3:4)=[1,0];
            else
                error('unknown regressor subtype (level 5). aborting...');
            end
        else
            error([num2str(j) 'unknown regressor subtype (level 3). aborting...']);
        end
        
        if strcmpi(selection{j,4},'vel') || strcmpi(selection{j,4},'normvel')  %  stimulus velocity
            if ambivalent==0
                rtemp3(:,2)=ismember(data(:,18:21),filter,'rows').*tempfreq;
            elseif ambivalent==1
                rtemp3(:,2)=(ismember(data(:,18:21),filter,'rows')|ismember(data(:,18:21),filter2,'rows')).*tempfreq;
            elseif ambivalent==2
                rtemp3(:,2)=(ismember(data(:,18:21),filter,'rows')|ismember(data(:,18:21),filter2,'rows')|ismember(data(:,18:21),filter3,'rows')).*tempfreq;
            end
            
            if strcmpi(selection{j,4},'normvel')
                rtemp3(:,2)=rtemp3(:,2)>0;
            end
            
        elseif strcmpi(selection{j,4},'active')
            rtemp3(:,2)=(data(:,choosedisp(1))>0).*(data(:,choosedisp(end))>0).*tempfreq>0;
        elseif strcmpi(selection{j,4},'anyactive')
            rtemp3(:,2)=(((data(:,18)>0)+(data(:,19)>0))>0).*tempfreq>0;
        elseif strcmpi(selection{j,4},'anyactiveDirSens')  % like anyactive but maintains the directionality of the stimulus
            rtemp3(:,2)=((((data(:,18)>0)+(data(:,19)>0))>0).*tempfreq>0).*-(data(:,20)*2-1);
        elseif strcmpi(selection{j,4},'onoffset')          % on- or offset of stimulus
            rtemp3(2:end,2)=(((data(2:end,18)>0)+(data(2:end,19)>0))>0).*abs(diff(tempfreqON))>0;
            rtemp3(1,2)=rtemp3(2,2);
            
        elseif strcmpi(selection{j,4},'onset')             % onset of stimulus
            rtemp3(2:end,2)=(((data(2:end,18)>0)+(data(2:end,19)>0))>0).*diff(tempfreqON)>0;
            rtemp3(1,2)=rtemp3(2,2);
        elseif strcmpi(selection{j,4},'offset')            % offset of stimulus
            rtemp3(2:end,2)=(((data(2:end,18)>0)+(data(2:end,19)>0))>0).*diff(tempfreqON)<0;
            rtemp3(1,2)=rtemp3(2,2);
        else
            error([num2str(j) 'invalid regressor subtype (level 4)']);
        end
        
    elseif strcmpi(selection{j,2},'AvgFrFl')               % Average Frame fluorescence
        regressorConv(j)=0;
        rtemp3=zeros(size(data,1),2);
        rtemp3(:,1)=data(:,1);
        rtemp3(:,2)=AvgFrFl;
    elseif strcmpi(selection{j,2},'StimBigArena')==0
        error([num2str(j) 'unknown regressor type (level 2). aborting.']);
    end
    
    outputregressors(:,j)=rtemp3(:,2);
end


