function [handle]=stimbarplot(R, RegionStats, RegressorNames)
%Bastian Hablitzel, 2013 (bastian.hablitzel@gmail.com)

handle=figure(14);
hold on;
labelsorig={'StimLEvelTN', 'StimLEvelNT', 'StimREvelTN', 'StimREvelNT', 'StimBEvelConjCW', 'StimBEvelConjCCW', 'StimBEvelConv', 'StimBEvelDiv'};
labels={'L-TN', 'L-NT', 'R-TN', 'R-NT', 'L-TN R-NT', 'L-NT R-TN', 'L-TN R-TN', 'L-NT R-NT'};

RStim=zeros(size(R,1),8);
for m=1:size(labels,2)
    index = find(cellfun(@(x) strcmpi(x,labelsorig{m}), RegressorNames));
    RStim(:,m)=R(:,index(1))>0;
    if isempty(index)
        error('At least one necessary Stim regressor missing. Aborting...');
    end;
end


intres=zeros(size(RegionStats,1),size(RStim,2));
for k=1:size(RegionStats,1); %for each cell
    for n=1:size(RStim,2) % for each stimulation type
        sta=find(diff(RStim(:,n))==1)+1; % detect interval start
        sto=find(diff(RStim(:,n))==-1)+1; % detect interval end
        
        if size(sta,1)==size(sto,1)+1 %if started stimulus does not end in recorded timeframe
            sto(1,end+1)=size(RStim,1); % set last frame as endpoint
        end
        
        temp=zeros(size(sta));
        for o=1:size(sta) % for each stimulation interval
            temp(o)=sum(RegionStats(k,1).DFF(sta(o):sto(o)))/(sto(o)-sta(o)); % Calculate integral of DFF divided by number of frames
        end
        
        intres(k,n)=sum(temp)/numel(temp); % Average multiple stimulation intervals
    end
end


for p=1:size(RegionStats,1);
    normintresrow=intres(p,:)/max(intres(p,:));
    scrollsubplot(10,1,p); % Matlab file exchange, by Bjorn Gustavsson
    bar(normintresrow);
    ylim([-0.2  1.2]);
    ylabel(['cell' num2str(p)]);
    set(gca, 'XTick', 1:8, 'XTickLabel', labels);
end

scrollsubplot(10,1,1);
title('Normalized relative cell response depending on stimulus direction');

end